4.10. umbra.components.factory.componentsManagerUi.componentsManagerUi — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.10. umbra.components.factory.componentsManagerUi.componentsManagerUi

componentsManagerUi.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `ComponentsManagerUi` Component Interface class.

Others:

## 4.10.1. Module Attributes

`umbra.components.factory.componentsManagerUi.componentsManagerUi.` `LOGGER`

`umbra.components.factory.componentsManagerUi.componentsManagerUi.` `COMPONENT_UI_FILE`

## 4.10.2. Classes

class `umbra.components.factory.componentsManagerUi.componentsManagerUi.` `ComponentsManagerUi`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `umbra.components.factory.componentsManagerUi.componentsManagerUi` Component Interface class.
  It defines methods to interact with the `manager.componentsManager.Manager` class Application instance Components.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `refreshNodes`

    This signal is emited by the `ComponentsManagerUi` class when `ComponentsManagerUi.model` class property model Nodes nodes needs to be refreshed. ( pyqtSignal )

  `activatedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is activated. ( pyqtSignal )

    Returns: | Activated Component name. ( String )

  `deactivatedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is deactivated. ( pyqtSignal )

    Returns: | Deactivated Component name. ( String )

  `reloadedComponent`

    This signal is emited by the `ComponentsManagerUi` class when a Component is reloaded. ( pyqtSignal )

    Returns: | Reloaded Component name. ( String )

  `uiResourcesDirectory`

    This method is the property for self.__uiResourcesDirectory attribute.

    Returns: | self.__uiResourcesDirectory. ( String )

  `uiActivatedImage`

    This method is the property for self.__uiActivatedImage attribute.

    Returns: | self.__uiActivatedImage. ( String )

  `uiDeactivatedImage`

    This method is the property for self.__uiDeactivatedImage attribute.

    Returns: | self.__uiDeactivatedImage. ( String )

  `uiCategoryAffixe`

    This method is the property for self.__uiCategoryAffixe attribute.

    Returns: | self.__uiCategoryAffixe. ( String )

  `dockArea`

    This method is the property for self.__dockArea attribute.

    Returns: | self.__dockArea. ( Integer )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `model`

    This method is the property for self.__model attribute.

    Returns: | self.__model. ( ComponentsModel )

  `view`

    This method is the property for self.__view attribute.

    Returns: | self.__view. ( QWidget )

  `headers`

    This method is the property for self.__headers attribute.

    Returns: | self.__headers. ( List )

  `treeViewInnerMargins`

    This method is the property for self.__treeViewInnerMargins attribute.

    Returns: | self.__treeViewInnerMargins. ( Integer )

  `componentsInformationsDefaultText`

    This method is the property for self.__componentsInformationsDefaultText attribute.

    Returns: | self.__componentsInformationsDefaultText. ( String )

  `componentsInformationsText`

    This method is the property for self.__componentsInformationsText attribute.

    Returns: | self.__componentsInformationsText. ( String )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`(*args, **kwargs)

    This method deactivates the Component.

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`(*args, **kwargs)

    This method uninitializes the Component ui.

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`(*args, **kwargs)

    This method removes the Component Widget from the engine.

  `onStartup`()

    This method is triggered on Framework startup.

    Returns: | Method success. ( Boolean )

  `activateComponentsUi`(*args, **kwargs)

    This decorator is used to encapsulate a processing operation.

    Parameters: | *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `deactivateComponentsUi`(*args, **kwargs)

    This decorator is used to encapsulate a processing operation.

    Parameters: | *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `reloadComponentsUi`(*args, **kwargs)

    This decorator is used to encapsulate a processing operation.

    Parameters: | *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `activateComponent`(*args, **kwargs)

    This method activates given Component.

    Parameters: | name – Component name. ( String )
    Returns: | Method success. ( Boolean )

  `deactivateComponent`(*args, **kwargs)

    This method deactivates given Component.

    Parameters: | name – Component name. ( String )
    Returns: | Method success. ( Boolean )

  `reloadComponent`(*args, **kwargs)

    This method reloads given Component.

    Parameters: | name – Component name. ( String )
    Returns: | Method success. ( Boolean )

  `getComponents`()

    This method returns the Components.

    Returns: | Components. ( List )

  `listComponents`()

    This method lists the Components names.

    Returns: | Components names. ( List )

  `setComponents`()

    This method sets the Components Model nodes.

  `getSelectedNodes`()

    This method returns the View selected nodes.

    Returns: | View selected nodes. ( Dictionary )

  `getSelectedComponentsNodes`()

    This method returns the View selected Components nodes.

    Returns: | View selected Components nodes. ( List )

  `getSelectedComponents`()

    This method gets the View selected Components.

    Returns: | View selected Components. ( List )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »